/*
GROWTH.PRG
Performs empirical work reported in

"Sample Splitting and Threshold Estimation"

Written by

Bruce E. Hansen
Department of Economics
Social Science Building
University of Wisconsin
Madison, WI 53706-1393
bhansen@ssc.wisc.edu
http://www.ssc.wisc.edu/~bhansen/

*/

@  Load procedures and data                  @

#include thr_est.prc;
#include thr_het.prc;
load data=dur_john;

@  Exclude missing variables and oil states  @

data = selif(data,1-(data[.,5].== -999));
data = selif(data,1-(data[.,6].== -999));
data = selif(data,1-(data[.,10].== -999));
data = selif(data,1-(data[.,11].== -999));
data = selif(data,data[.,2]);

@  Make data transformations                 @

diff=ln(data[.,6])-ln(data[.,5]);
q = data[.,5];
gdp60=ln(q);
iony=ln(data[.,9]/100);
pgro=ln(data[.,8]/100+.05);
sch=ln((data[.,10])/100);
lit = data[.,11];
dat=diff~gdp60~iony~pgro~sch~q~lit;

@  Program switches                          @

rep = 1000;
h   = 1;
na  = { GNP_Gwth, GDP_1960, Inv/GDP, Pop_Gwth, School, GDP_1960, Literacy };
dum = 2|3|4|5;
output file=growth.out reset;


"Testing for a First Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dat,1,dum,6,0.15,1000);
"";"";
"Testing for a First Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dat,1,dum,7,0.15,1000);
"";"";

@  Estimate First Sample Split, Using Output as Threshold @

qhat1 = thr_est(dat,na,1,dum,6,h);


@  Second Level @

i = (q .> qhat1);
dati = selif(dat,i);
"Sub-Sample, Incomes over 863";
"Testing for a Second Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dati,1,dum,6,0.15,1000);
"";"";
"Testing for a Second Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dati,1,dum,7,0.15,1000);
"";"";

@  Estimate Second Sample Split, Using Literacy Rate as Threshold @

qhat2 = thr_est(dati,na,1,dum,7,h);


@  Third Level @

i1 = (lit .<= qhat2).*i;
i2 = (lit .>  qhat2).*i;
dat1 = selif(dat,i1);
dat2 = selif(dat,i2);
"Sub-Sample, Incomes over 863, Literacy Under 45";
"Testing for a Third Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dat1,1,dum,6,0.15,1000);
"";"";
"Testing for a Third Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dat1,1,dum,7,0.15,1000);
"";"";
"Sub-Sample, Incomes over 863, Literacy Over 45";
"Testing for a Third Sample Split, Using Output";
"";
{f_test,p_value}=thr_het(dat2,1,dum,6,0.15,1000);
"";"";
"Testing for a Third Sample Split, Using Literacy Rate";
"";
{f_test,p_value}=thr_het(dat2,1,dum,7,0.15,1000);
"";"";

output off;



